AuthError

Enum AuthError 

pub enum AuthError {
    NotMember {
        sender: String,
    },
    InsufficientPowerLevel {
        required: i64,
        actual: i64,
        event_type: String,
    },
    BannedUser {
        sender: String,
    },
    InvalidStateKey {
        expected: String,
        actual: String,
    },
    CreateWithPrevEvents,
    MissingAuthEvent(String),
}
An error indicating why an event failed authorization.

Variants



NotMember

The sender is not a member of the room (or membership is not “join”).

Fields

sender: String


InsufficientPowerLevel

The sender’s power level is below the required level for this event type.

Fields

required: i64
actual: i64
event_type: String


BannedUser

The sender is banned from the room.

Fields

sender: String


InvalidStateKey

For m.room.member events, the state_key doesn’t match the expected user ID for the given membership transition.

Fields

expected: String
actual: String


CreateWithPrevEvents

The m.room.create event has prev_events, which is forbidden.



MissingAuthEvent(String)

An auth event referenced by this event is missing from the provided state.